#!/usr/bin/env python
# PYTHON_ARGCOMPLETE_OK

# Copyright 2017 The Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import argcomplete
import argparse
import logging
import pkg_resources
import sys
import pprint
import json
from prettytable import PrettyTable

from advisor_client.client import AdvisorClient
from advisor_client.runner.runner_launcher import RunnerLauncher

logging.basicConfig(level=logging.DEBUG)
# Disable debug log from requests and urllib3
logging.getLogger("requests").setLevel(logging.WARNING)
logging.getLogger("urllib3").setLevel(logging.WARNING)


def print_studies(studies):
  print("{:16} {:16} {:16} {:16} {:32} {:32}".format(
      "ID", "NAME", "CONFIGURATION", "STATUS", "CREATED", "UPDATED"))

  for study in studies:
    print("{:16} {:16} {:16} {:16} {:32} {:32}".format(
        study.id, study.name, study.study_configuration, study.status,
        study.created_time, study.updated_time))


def print_studies_as_table(studies):
  table = PrettyTable()
  table.field_names = [
      "Id", "Name", "Configuration", "Status", "Create", "Updated"
  ]

  for study in studies:
    table.add_row([
        study.id, study.name, study.study_configuration, study.status,
        study.created_time, study.updated_time
    ])

  print(table)


def print_trials(trials):
  print("{:16} {:16} {:16} {:16} {:16} {:16} {:32} {:32}".format(
      "ID", "STUDY", "NAME", "PARAMETER", "OBJECTIVE", "STATUS", "CREATED",
      "UPDATED"))

  for trial in trials:
    print("{:16} {:16} {:16} {:16} {:16} {:16} {:32} {:32}".format(
        trial.id, trial.study_name, trial.name, trial.parameter_values,
        trial.objective_value, trial.status, trial.created_time,
        trial.updated_time))


def print_trials_as_table(trials):
  table = PrettyTable()
  table.field_names = [
      "Id", "Study", "Name", "PARAMETER", "Objective", "Status", "Create",
      "Updated"
  ]

  for trial in trials:
    table.add_row([
        trial.id, trial.study_name, trial.name, trial.parameter_values,
        trial.objective_value, trial.status, trial.created_time,
        trial.updated_time
    ])
  print(table)


def list_studies(args):
  client = AdvisorClient()
  print_studies_as_table(client.list_studies())


def describe_studie(args):
  client = AdvisorClient()
  study = client.get_study_by_name(args.study_name)

  # Print study
  table = PrettyTable()
  table.field_names = [
      "Id", "Name", "Algorithm", "Status", "Create", "Updated"
  ]
  table.add_row([
      study.id, study.name, study.algorithm, study.status, study.created_time,
      study.updated_time
  ])
  print(table)

  # Print study configuration
  """
  table = PrettyTable()
  table.field_names = ["Configuration"]
  table.add_row([study.study_configuration])
  print(table)
  """
  pprint.pprint(json.loads(study.study_configuration))

  # Print related trials
  study_trials = client.list_trials(args.study_name)
  if (len(study_trials)) > 0:
    print_trials_as_table(study_trials)


def list_trials(args):
  client = AdvisorClient()
  print_trials_as_table(client.list_trials(args.study_name))


def run_with_file(args):
  launcher = RunnerLauncher(args.run_file)
  launcher.run()


def main():
  parser = argparse.ArgumentParser()

  parser.add_argument(
      "-v",
      "--version",
      action="version",
      version=pkg_resources.require("advisor-areeh-fork")[0].version,
      help="Display sdk version")

  main_subparser = parser.add_subparsers(dest="command_group", help="Commands")

  # subcommand: study
  study_parser = main_subparser.add_parser(
      "study", help="Commands about study")
  study_subparser = study_parser.add_subparsers(
      dest="study_command", help="Subcommands of study")

  # subcommand: study list
  study_list_parser = study_subparser.add_parser("list", help="List studies")
  study_list_parser.set_defaults(func=list_studies)

  # subcommand: study describe
  study_describe_parser = study_subparser.add_parser(
      "describe", help="Describe studiy")
  study_describe_parser.add_argument(
      "-s",
      "--study_name",
      dest="study_name",
      help="The id of the resource",
      required=True)
  study_describe_parser.set_defaults(func=describe_studie)

  # subcommand: trial
  trial_parser = main_subparser.add_parser(
      "trial", help="Commands about trial")
  trial_subparser = trial_parser.add_subparsers(
      dest="trial_command", help="Subcommands of trial")

  # subcommand: trial list
  trial_list_parser = trial_subparser.add_parser("list", help="List trials")
  trial_list_parser.add_argument(
      "-s",
      "--study_name",
      dest="study_name",
      help="The id of the resource",
      required=True)
  trial_list_parser.set_defaults(func=list_trials)

  # subcommand: run
  run_parser = main_subparser.add_parser("run", help="Commands about run")
  run_parser.add_argument(
      "-f", "--file", dest="run_file", help="The run file", required=True)
  run_parser.set_defaults(func=run_with_file)

  # Display help information by default
  if len(sys.argv) == 1:
    args = parser.parse_args(["-h"])
  else:
    args = parser.parse_args(sys.argv[1:])
  args.func(args)


if __name__ == "__main__":
  main()



import six


class Study(object):
  def __init__(self,
               name,
               study_configuration,
               algorithm="BayesianOptimization",
               id=None,
               status=None,
               created_time=None,
               updated_time=None):
    self.id = id
    if six.PY2:
      self.name = name.encode("utf-8")
    else:
      self.name = name
    self.study_configuration = study_configuration
    self.algorithm = algorithm
    self.status = status
    self.created_time = created_time
    self.updated_time = updated_time

  def __str__(self):
    return "Id: {}, name: {}, study_configuration: {}, algorithm: {}".format(
        self.id, self.name, self.study_configuration, self.algorithm)

  def to_dict(self):
    return {
        "name": self.name,
        "study_configuration": self.study_configuration,
        "algorithm": self.algorithm
    }

  @classmethod
  def from_dict(self, dict):
    return Study(dict["name"], dict["study_configuration"], dict["algorithm"],
                 dict["id"], dict["status"], dict["created_time"],
                 dict["updated_time"])


class Trial(object):
  def __init__(self,
               study_name,
               name,
               parameter_values=None,
               objective_value=None,
               id=None,
               status=None,
               created_time=None,
               updated_time=None):
    self.id = id
    if six.PY2:
      self.study_name = study_name.encode("utf-8")
    else:
      self.study_name = study_name
    self.name = name
    self.parameter_values = parameter_values
    self.objective_value = objective_value
    self.status = status
    self.created_time = created_time
    self.updated_time = updated_time

  def __str__(self):
    return "Id: {}, study_name: {}, name: {}, parameter_values: {}, objective_value: {}".format(
        self.id, self.study_name, self.name, self.parameter_values,
        self.objective_value)

  def to_dict(self):
    return {"study_name": self.study_name, "name": self.name}

  @classmethod
  def from_dict(self, dict):
    return Trial(dict["study_name"], dict["name"], dict["parameter_values"],
                 dict["objective_value"], dict["id"], dict["status"],
                 dict["created_time"], dict["updated_time"])


class TrialMetric(object):
  def __init__(self,
               trial_id,
               training_step,
               objective_value,
               id=None,
               created_time=None,
               updated_time=None):
    self.id = id
    self.trial_id = trial_id
    self.training_step = training_step
    self.objective_value = objective_value
    self.created_time = created_time
    self.updated_time = updated_time

  def __str__(self):
    return "Id: {}, trial_id: {}, training_step: {}, objective_value: {}".format(
        self.id, self.trial_id, self.training_step, self.objective_value)

  def to_dict(self):
    return {
        "trial_id": self.trial_id,
        "training_step": self.training_step,
        "objective_value": self.objective_value
    }

  @classmethod
  def from_dict(self, dict):
    return TrialMetric(dict["trial_id"], dict["training_step"],
                       dict["objective_value"], dict["id"],
                       dict["created_time"], dict["updated_time"])



import abc


class AbstractRunner(object):

  __metaclass__ = abc.ABCMeta

  @abc.abstractmethod
  def run(self, study_name, trials=[], number=1):
    """
        The study's study_configuration is like this.
        {
              "goal": "MAXIMIZE",
              "maxTrials": 5,
              "maxParallelTrials": 1,
              "params": [
                  {
                      "parameterName": "hidden1",
                      "type": "INTEGER",
                      "minValue": 40,
                      "maxValue": 400,
                      "scalingType": "LINEAR"
                  }
              ]
          }
        
        The trial's parameter_values_json should be like this.
        {
              "hidden1": 40
        }
        
        Args:
          study_name: The study name.
          trials: The all trials of this study.
          number: The number of trial to return. 
        Returns:
          The array of trial objects.
        """
    raise NotImplementedError



#!/usr/bin/env python
# PYTHON_ARGCOMPLETE_OK

# Copyright 2017 The Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import argcomplete
import argparse
import logging
import pkg_resources
import sys
import subprocess

logging.basicConfig(level=logging.DEBUG)
# Disable debug log from requests and urllib3
logging.getLogger("requests").setLevel(logging.WARNING)
logging.getLogger("urllib3").setLevel(logging.WARNING)

PY2 = sys.version_info[0] == 2
PY3 = sys.version_info[0] == 3

if PY2:
  raw_input = raw_input
else:
  raw_input = input


def start_server(args):

  if is_server_running() == True:
    print("Server running, do not start again")
    return
  
  if args.server_start_noprompt:
    choice = "y"
  else:
    choice = raw_input("Are you sure to run server container(Y/N): ").lower()

  if choice in ("y", "yes"):
    print("Try to start the server with container")

    command = "docker run -d -p {}:8000 tobegit3hub/advisor".format(args.port)
    if args.command_args != None:
      command += " " + args.command_args
    print("Run the command: {}".format(command))

    exit_code = subprocess.call(command, shell=True)

    if exit_code != 0:
      print("Fail to run server, exit code: {}".format(exit_code))
    else:
      print("Success to start the server, please access http://127.0.0.1:{}".
            format(args.port))

  else:
    print("Cancel operation")


def stop_server(args):

  if is_server_running() == False:
    print("Server not running, do not stop again")
    return

  choice = raw_input("Are you sure to stop server container(Y/N): ").lower()
  if choice in ("y", "yes"):
    print("Try to start the server with container")

    command = "docker ps |grep 'tobegit3hub/advisor' | awk '{print $1}' | xargs docker stop"
    print("Run the command: {}".format(command))

    exit_code = subprocess.call(command, shell=True)

    if exit_code != 0:
      print("Fail to stop server, exit code: {}".format(exit_code))
    else:
      print("Success to stop the server")

  else:
    print("Cancel operation")


def check_server_status(args):

  print("Try to get status of the server container")
  if is_server_running():
    print("Server running")
  else:
    print("Server not running")


def is_server_running():

  command = "docker ps |grep 'tobegit3hub/advisor'"
  print("Run the command: {}".format(command))

  try:
    command_output = subprocess.check_output(command, shell=True)

    if command_output != "":
      return True

  except subprocess.CalledProcessError as e:
    if e.output == "":
      pass
    else:
      print("Get error: {}".format(e.output))
    return False


def main():
  parser = argparse.ArgumentParser()

  parser.add_argument(
      "-v",
      "--version",
      action="version",
      version=pkg_resources.require("advisor-areeh-fork")[0].version,
      help="Display sdk version")

  main_subparser = parser.add_subparsers(dest="command_group", help="Commands")

  # subcommand: study
  server_parser = main_subparser.add_parser(
      "server", help="Commands about server")
  server_subparser = server_parser.add_subparsers(
      dest="server_command", help="Subcommands of server")

  # subcommand: server start
  server_start_parser = server_subparser.add_parser(
      "start", help="Commands about server start")
  server_start_parser.add_argument(
      "-p",
      "--port",
      dest="port",
      nargs='?',
      const=8000,
      default=8000,
      type=int,
      help="The port",
      required=False)
 
  server_start_parser.add_argument(
    "-y",
    dest="server_start_noprompt",
    default=False,
    action="store_const",
    const=True,
    help="Answer yes to the start server prompt. Useful for daemonizing the server."
  )
  
  server_start_parser.add_argument(
      "--command_args",
      dest="command_args",
      help="The extrs command args",
      required=False)
  server_start_parser.set_defaults(func=start_server)

  # subcommand: server stop
  server_stop_parser = server_subparser.add_parser(
      "stop", help="Commands about server stop")
  server_stop_parser.set_defaults(func=stop_server)

  # subcommand: server status
  server_status_parser = server_subparser.add_parser(
      "status", help="Commands about server status")
  server_status_parser.set_defaults(func=check_server_status)

  # Display help information by default
  if len(sys.argv) == 1:
    args = parser.parse_args(["-h"])
  else:
    args = parser.parse_args(sys.argv[1:])
  args.func(args)


if __name__ == "__main__":
  main()



import unittest

from .local_runner import LocalRunner


class TestLocalRunner(unittest.TestCase):
  def test(self):
    self.assertEqual(1, 1)

  def test2(self):
    runner = LocalRunner()
    self.assertEqual(2, 2)



import json
import yaml
import logging
import subprocess
import coloredlogs
import six

from .abstract_runner import AbstractRunner
from .local_runner import LocalRunner

from advisor_client.client import AdvisorClient

logging.basicConfig(
    format='%(asctime)s %(levelname)-8s %(message)s',
    level=logging.DEBUG,
    datefmt='%Y-%m-%d %H:%M:%S')

logger = logging.getLogger("simple_tensorflow_serving")
logger.setLevel(logging.DEBUG)

coloredlogs.install(
    level='DEBUG', logger=logger, fmt='%(asctime)s %(levelname)s %(message)s')


class RunnerLauncher():
  def __init__(self, run_file=None):

    # Example: {u'name': u'simple1', u'algorithm': u'RandomSearch', u'runner': u'local_runner', u'search_space': {u'maxTrials': 5, u'params': [{u'scalingType': u'LINEAR', u'type': u'DOUBLE', u'maxValue': 0.01, u'minValue': 0.001, u'parameterName': u'gamma', u'feasiblePoints': u''}], u'randomInitTrials': 1, u'goal': u'MINIMIZE', u'maxParallelTrials': 1}, u'trialNumber':3, u'concurrency': 1, u'path': u'~/code/', u'command': u'python ./simple_function.py'}
    self.run_config_dict = {}

    with open(run_file, "r") as f:

      if run_file.endswith(".json"):
        self.run_config_dict = json.load(f)
      elif run_file.endswith(".yml") or run_file.endswith(".yaml"):
        self.run_config_dict = yaml.safe_load(f)
      else:
        logging.error("Unsupport config file format, use json or yaml")

      logging.info("Run with config: {}".format(self.run_config_dict))

  def run(self):
    client = AdvisorClient()

    self.run_config_dict

    # TODO: move the logic into local runner
    runner = LocalRunner()
    if "runner" in self.run_config_dict:
      if self.run_config_dict["runner"] == "local_runner":
        runner = LocalRunner()
        logging.info("Run with local runner")

    if six.PY2:
      study_name = self.run_config_dict["name"].encode("utf-8")
    else:
      study_name = self.run_config_dict["name"]
    study = client.get_or_create_study(study_name,
                                       self.run_config_dict["search_space"],
                                       self.run_config_dict["algorithm"])

    logging.info("Create study: {}".format(study))

    for i in range(self.run_config_dict["trialNumber"]):

      logging.info("-------------------- Start Trial --------------------")

      # Get suggested trials
      trials = client.get_suggestions(study.name, 1)

      logging.info("Get trial: {}".format(trials[0]))

      #import ipdb;ipdb.set_trace()

      # Generate parameters
      parameter_value_dicts = []
      for trial in trials:
        parameter_value_dict = json.loads(trial.parameter_values)
        logging.info(
            "The suggested parameters: {}".format(parameter_value_dict))
        parameter_value_dicts.append(parameter_value_dict)

      # Run training

      for trial in trials:
        #metric = train_function(**parameter_value_dicts[i])

        # Example: {"gamma": 0.0063987614450157415}
        parameters_dict = json.loads(trials[0].parameter_values)
        parameter_string = ""

        for k, v in parameters_dict.items():
          parameter_string += " -{}={}".format(k, v)

        command_string = "cd {} && {} {}".format(
            self.run_config_dict["path"], self.run_config_dict["command"],
            parameter_string)

        #exit_code = subprocess.call(command_string, shell=True)
        logging.info("Run the command: {}".format(command_string))

        # Example: '0.0\n'
        # Example: 'Compute y = x * x - 3 * x + 2\nIput x is: 1.0\nOutput is: 0.0\n0.0\n'
        if six.PY2:
          command_output = subprocess.check_output(command_string, shell=True)
        else:
          command_output = subprocess.check_output(command_string, universal_newlines=True, shell=True)
        # TODO: Log the output in the directory
        #logging.info("Get output of command: {}".format(command_output))

        metric = float(command_output.split("\n")[-2].strip())
        # Complete the trial
        client.complete_trial_with_one_metric(trial, metric)
        logging.info("Update the trial with metrics: {}".format(metric))

      logging.info("--------------------- End Trial ---------------------")

    is_done = client.is_study_done(study.name)
    best_trial = client.get_best_trial(study.name)
    logging.info("The study: {}, best trial: {}".format(study, best_trial))



import os
import json
import requests

from .model import Study
from .model import Trial
from .model import TrialMetric


class AdvisorClient(object):
  def __init__(self, endpoint=None):
    # TODO: Read endpoint from configuration file
    if endpoint != None:
      self.endpoint = endpoint

    elif "ADVISOR_ENDPOINT" in os.environ:
      self.endpoint = os.environ.get("ADVISOR_ENDPOINT")

    else:
      self.endpoint = "http://0.0.0.0:8000"

  def create_study(self,
                   study_name,
                   study_configuration,
                   algorithm="BayesianOptimization"):
    url = "{}/suggestion/v1/studies".format(self.endpoint)
    request_data = {
        "name": study_name,
        "study_configuration": study_configuration,
        "algorithm": algorithm
    }
    response = requests.post(url, json=request_data)

    study = None
    if response.ok:
      study = Study.from_dict(response.json()["data"])

    return study

  def get_or_create_study(self,
                          study_name,
                          study_configuration,
                          algorithm="BayesianOptimization"):

    url = "{}/suggestion/v1/studies/{}/exist".format(self.endpoint, study_name)
    response = requests.get(url)
    study_exist = response.json()["exist"]

    if study_exist == True:
      study = self.get_study_by_name(study_name)
    else:
      study = self.create_study(study_name, study_configuration, algorithm)

    return study

  def list_studies(self):
    url = "{}/suggestion/v1/studies".format(self.endpoint)
    response = requests.get(url)
    studies = []

    if response.ok:
      dicts = response.json()["data"]
      for dict in dicts:
        study = Study.from_dict(dict)
        studies.append(study)

    return studies

  # TODO: Support load study by configuration and name
  def get_study_by_name(self, study_name):
    url = "{}/suggestion/v1/studies/{}".format(self.endpoint, study_name)
    response = requests.get(url)
    study = None

    if response.ok:
      study = Study.from_dict(response.json()["data"])

    return study

  def get_suggestions(self, study_id, trials_number=1):
    url = "{}/suggestion/v1/studies/{}/suggestions".format(
        self.endpoint, study_id)
    request_data = {"trials_number": trials_number}
    response = requests.post(url, json=request_data)
    trials = []

    if response.ok:
      dicts = response.json()["data"]
      for dict in dicts:
        trial = Trial.from_dict(dict)
        trials.append(trial)

    return trials

  def is_study_done(self, study_name):
    study = self.get_study_by_name(study_name)
    is_completed = True

    if study.status == "Completed":
      return True

    trials = self.list_trials(study_name)

    if len(trials) == 0:
      return False

    for trial in trials:
      if trial.status != "Completed":
        return False

    url = "{}/suggestion/v1/studies/{}".format(self.endpoint, trial.study_name)
    request_data = {"status": "Completed"}
    response = requests.put(url, json=request_data)

    return is_completed

  def list_trials(self, study_name):
    url = "{}/suggestion/v1/studies/{}/trials".format(self.endpoint,
                                                      study_name)
    response = requests.get(url)
    trials = []

    if response.ok:
      dicts = response.json()["data"]
      for dict in dicts:
        trial = Trial.from_dict(dict)
        trials.append(trial)

    return trials

  def list_trial_metrics(self, study_name, trial_id):
    url = "{}/suggestion/v1/studies/{}/trials/{}/metrics".format(
        self.endpoint, study_name)
    response = requests.get(url)
    trial_metrics = []

    if response.ok:
      dicts = response.json()["data"]
      for dict in dicts:
        trial_metric = TrialMetric.from_dict(dict)
        trial_metrics.append(trial_metric)

    return trial_metrics

  def get_best_trial(self, study_name):
    if not self.is_study_done:
      return None

    study = self.get_study_by_name(study_name)
    study_configuration_dict = json.loads(study.study_configuration)
    study_goal = study_configuration_dict["goal"]
    trials = self.list_trials(study_name)

    best_trial = None
    best_objective_value = None

    # Get the first not null trial
    for trial in trials:
      if trial.objective_value:
        best_objective_value = trial.objective_value
        best_trial = trial
        break

    if best_trial == None:
      return None

    for trial in trials:
      if study_goal == "MAXIMIZE":
        if trial.objective_value and trial.objective_value > best_objective_value:
          best_trial = trial
          best_objective_value = trial.objective_value
      elif study_goal == "MINIMIZE":
        if trial.objective_value and trial.objective_value < best_objective_value:
          best_trial = trial
          best_objective_value = trial.objective_value
      else:
        return None

    return best_trial

  def get_trial(self, study_name, trial_id):
    url = "{}/suggestion/v1/studies/{}/trials/{}".format(
        self.endpoint, study_name, trial_id)
    response = requests.get(url)
    trial = None

    if response.ok:
      trial = Trial.from_dict(response.json()["data"])

    return trial

  def create_trial_metric(self, study_name, trial_id, training_step,
                          objective_value):
    url = "{}/suggestion/v1/studies/{}/trials/{}/metrics".format(
        self.endpoint, study_name, trial_id)
    request_data = {
        "training_step": training_step,
        "objective_value": objective_value
    }
    response = requests.post(url, json=request_data)

    study = None
    if response.ok:
      trial_metric = TrialMetric.from_dict(response.json()["data"])

    return trial_metric

  def complete_trial_with_tensorboard_metrics(self, trial,
                                              tensorboard_metrics):
    for tensorboard_metric in tensorboard_metrics:
      self.create_trial_metric(trial.study_name, trial.id,
                               tensorboard_metric.step,
                               tensorboard_metric.value)

    url = "{}/suggestion/v1/studies/{}/trials/{}".format(
        self.endpoint, trial.study_name, trial.id)
    objective_value = tensorboard_metrics[-1].value
    request_data = {"status": "Completed", "objective_value": objective_value}

    response = requests.put(url, json=request_data)

    if response.ok:
      trial = Trial.from_dict(response.json()["data"])

    return trial

  def complete_trial_with_one_metric(self, trial, metric):
    self.create_trial_metric(trial.study_name, trial.id, None, metric)

    url = "{}/suggestion/v1/studies/{}/trials/{}".format(
        self.endpoint, trial.study_name, trial.id)
    objective_value = metric
    request_data = {"status": "Completed", "objective_value": objective_value}

    response = requests.put(url, json=request_data)

    if response.ok:
      trial = Trial.from_dict(response.json()["data"])

    return trial



# Copyright 2017.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# twine upload dist/advisor-x.x.x.tar.gz
# twine upload dist/advisor-x.x.x.tar.gz -r test
# pip install --index-url https://test.pypi.org/simple/ --upgrade advisor

from setuptools import setup, find_packages

setup(
    name="advisor-areeh-fork",
    version="0.1.6.2",
    author="areeh",
    author_email="arehaartveit@gmail.com",
    url="https://github.com/areeh/advisor",
    install_requires=["requests>=2.6.0", "pyOpenSSL>=16.1.0",
                      "argcomplete>=1.4.1", "prettytable", "coloredlogs", "pyyaml"],
    description=
    "Advisor is the hyper parameters tuning system for black box optimization",
    # packages=["advisor_client"],
    packages=find_packages(),
    zip_safe=False,
    entry_points={
        "console_scripts": [
            "advisor=advisor_client.commandline.command:main",
            "advisor_admin=advisor_client.commandline.admin_command:main"
        ],
    })
